OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Je creëerde tweefactorauthenticatie back-upcodes voor je account",
    "Second-factor backup codes" : "Tweefactorauthenticatie back-upcode",
    "Generate backup codes" : "Genereer back-upcode",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Je hebt tweefactorauthenticatie ingeschakeld, maar nog geen back-upcodes gegenereerd. Die zijn nodig voor het ontgrendelen van je account in het geval dat je je tweede factor (zoals een mobiele telefoon) kwijt bent.",
    "Backup code" : "Back-upcode",
    "Use backup code" : "Gebruik back-upcode",
    "Two factor backup codes" : "Twee-factor back-upcode",
    "A two-factor auth backup codes provider" : "Een tweefactor authenticatie back-upcodes provider",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Back-upcodes zijn gegenereerd. {used} van {total} codes zijn gebruikt.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dit zijn je back-upcodes. Bewaar ze en/of druk ze alsjeblieft af, want je ze kunt niet later nog een keer opvragen.",
    "Save backup codes" : "Bewaren back-upcode",
    "Print backup codes" : "Afdrukken back-upcode",
    "Regenerate backup codes" : "Regenereer back-upcode",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Als je back-upcodes opnieuw genereert, worden oude codes automatisch ongeldig gemaakt.",
    "An error occurred while generating your backup codes" : "Er trad een fout op bij het genereren van je back-upcodes",
    "{name} backup codes" : "{name} back-upcodes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Gebruik een van de back-upcodes die je bewaarde bij het inschakelen van de tweefactorauthenticatie.",
    "Submit" : "Verwerken"
},
"nplurals=2; plural=(n != 1);");
